@@ -62,7 +62,7 @@ from vdsm.common.compat import pickle
 from vdsm.common.define import doneCode, errCode
 from vdsm.config import config
 from vdsm.virt import sampling
-from vdsm.virt.domain_descriptor import DomainDescriptor
+from vdsm.virt.domain_descriptor import DomainDescriptor, XmlSource
 import vdsm.virt.jobs
 from vdsm.virt.jobs import seal
 from vdsm.virt.vmdevices import graphics
@@ -190,7 +190,7 @@ class VM(APIBase):
         """
         # self._UUID is None in this call, it must be retrieved from XML
         xml = vmParams.get('_srcDomXML') or vmParams['xml']
-        self._UUID = DomainDescriptor(xml, initial=True).id
+        self._UUID = DomainDescriptor(xml, xml_source=XmlSource.INITIAL).id
         vmParams['vmId'] = self._UUID
         try:
             if vmParams.get('vmId') in self._cif.vmContainer:
